predictPlot <- function(y, quantiles, FINprognose, plot.options)
{
  ##make dataForPlot:
  dataForPlot <- matrix(NA, length(y), 2)
  colnames(dataForPlot) <- c("MeanActual", "MeanPrediction")
  dataForPlot[1:5,"MeanActual"] <- coredata(y[1:5])
  dataForPlot[6:8,"MeanActual"] <- FINprognose
  dataForPlot[6:8,"MeanPrediction"] <- coredata(y[6:8])
  dataForPlot <- zoo(dataForPlot, order.by=index(y))

  ##create polygon index:
  n.ahead <- 3
  i1 <- ifelse(plot.options$start.at.origin, 0, 1)
  polygonIndx <- c(NROW(dataForPlot)-n.ahead+i1):NROW(dataForPlot)
  polygonIndx <- c(polygonIndx, polygonIndx[c(length(polygonIndx):1)])
  polygonIndx <- index(dataForPlot)[polygonIndx]

  ##matrices with the ci's:
  ciLower <- c(0.10, 0.25)
  ciUpper <- c(0.90, 0.75)
  mMeanQs <- quantiles
  mCiLowerValsMean <- cbind(coredata(mMeanQs[,as.character(ciLower)]))
  colnames(mCiLowerValsMean) <- as.character(ciLower)
  mCiUpperValsMean <- cbind(coredata(mMeanQs[,as.character(ciUpper)]))
  colnames(mCiUpperValsMean) <- as.character(ciUpper)
  mCiUpperValsMean <-
    mCiUpperValsMean[NROW(mCiUpperValsMean):1,] #invert (first to last, last to first)
  if(n.ahead==1){ ##ensure they are still matrices:
    mCiLowerValsMean <- rbind(mCiLowerValsMean)
    mCiUpperValsMean <- rbind(mCiUpperValsMean)
  }

  ##add actual value at forecast origin to ci matrices?:
  if( plot.options$start.at.origin ){
    actualValue <- coredata(dataForPlot[5,"MeanActual"])
    mCiLowerValsMean <- rbind(actualValue, mCiLowerValsMean)
    mCiUpperValsMean <- rbind(mCiUpperValsMean, actualValue)
    dataForPlot[5,"MeanPrediction"] <- actualValue
  }

  ##y-axis (limits):
  if( is.null(plot.options$ylim) ){
    ylimArg <- as.vector(dataForPlot)
    ylimArg <- c(coredata(mCiLowerValsMean[,1]),
      coredata(mCiUpperValsMean[,1]), ylimArg)
    ylimArg <- range(ylimArg, na.rm=TRUE)
    vlineTopValue <- ylimArg[2] #for vertical line (further below)
    eps <- abs(ylimArg[2]-ylimArg[1])
    ylimArg[2] <- ylimArg[2] + eps*0.15 #add more space at the top
    ylimArg[1] <- ylimArg[1] - eps*0.05 #add more space at the bottom

  }else{ ylimArg <- plot.options$ylim }

  ##plot:
  ##=====
  
  ##shades of grey:
  ciLevelsArg <- c(0.5,0.8)
  shadesOfGrey <- 40:90 #1 to 100 is possible
  shadesOfGrey <- quantile(shadesOfGrey, probs=ciLevelsArg)
  shadesOfGrey <- shadesOfGrey[length(shadesOfGrey):1] #invert, i.e. last to first
  plot.options$shades <- round(as.numeric(shadesOfGrey))
  greySelection <- paste0("grey", plot.options$shades)

  ##if "main" argument:
  if( is.null(plot.options$main) ){
    parMarVals <- c(2.1,3.1,0.6,0.6) #bottom,left,top,right
  }else{
    parMarVals <- c(2.1,3.1,1.5,0.6) #bottom,left,top,right
  }

  ##get current par-values:
  def.par <- par(no.readonly=TRUE)

  ##margins:
  par(mar=parMarVals)

  ##plot actual values in white (i.e. create plot):
  plot.zoo(dataForPlot[,"MeanActual"], xlab="", ylab="",
    main=plot.options$main, lty=plot.options$lty[2],
    col="white", lwd=plot.options$lwd[2], ylim=ylimArg)

  ##add start line?:
  if( plot.options$line.at.origin ){
    startlineIndx <- rep( index(dataForPlot)[5], 2)
    eps <- abs(ylimArg[2]-ylimArg[1])
    startlineVals <- c(ylimArg[1]-eps*0.05, vlineTopValue)
    polygon(startlineIndx, startlineVals, col="grey",
      border="grey", lwd=plot.options$lwd)
  }

  ##add ci's:
  for(i in 1:length(ciLevelsArg)){
    polygon( polygonIndx,
      c(mCiLowerValsMean[,i],mCiUpperValsMean[,i]),
      col=greySelection[i], border=greySelection[i] )
  }

  ##add horisontal lines?:
  if(!is.null(plot.options$hlines)){
    abline(h=plot.options$hlines, col="grey", lty=3)
  }

  ##add prediction:
  lines(dataForPlot[,"MeanPrediction"], lty=plot.options$lty[1],
    col=plot.options$col[1], lwd=plot.options$lwd[1])

  ##add actual:
  lines(dataForPlot[,"MeanActual"], lty=plot.options$lty[2],
    col=plot.options$col[2], lwd=plot.options$lwd[2], type="l")

  ##add point at forecast origin?:
  if( plot.options$dot.at.origin ){
    points(index(dataForPlot)[5],
      dataForPlot[5,"MeanActual"],
      pch=19, col=plot.options$col[2], lwd=plot.options$lwd[2])
  }

  ##add text closer to plot than xlab or ylab would do
  mtextValue <- ifelse(is.null(plot.options$ylab),
    "Mean", plot.options$ylab)
  mtext(mtextValue, side=2, line=2)

  ##add plot-legend:
  legend("top", lty=plot.options$lty, col=plot.options$col,
    lwd=plot.options$lwd, legend=plot.options$legend.text,
    bg="white", bty="n")

  ##add ci-legend:
  legendArg <- ciLevelsArg[length(ciLevelsArg):1]*100
  legendArg <- paste0(legendArg, "%")
  legend("topright", lty=c(1,1), lwd=13, bty="n",
    col=greySelection[c(1,length(ciLevelsArg))],
    legend=legendArg[c(1,length(ciLevelsArg))])

  ##return to old par-values:
  par(def.par)

} ##close predictPlot function